#include <iostream>
#include <string>
#include <vector>

#include "appl_grid/appl_grid.h"
#include "appl_grid/appl_timer.h"

#include "TH1D.h"
#include "TPad.h"


// lhapdf routines
#include "LHAPDF/LHAPDF.h"
extern "C" void evolvepdf_(const double& , const double& , double* ); 
extern "C" double alphaspdf_(const double& Q);



int main(int argc, char** argv) { 



  // use a default atlas inclusive grid
  std::string gridname = "atlas-incljets04-eta1.root";

  if ( argc>1 ) gridname = argv[1];

  std::cout << "reading grid " << gridname << std::endl; 

  // get name of grid from user and create from grid file
  appl::grid g(gridname);

  g.trim(); // trim away uneeded memory

  /// print the grid documentation 
  std::cout << g.getDocumentation() << std::endl; 

  





  // initialise lhapdf

  std::cout << "setting up lhapdf" << std::endl; 

  const string _pdfname = "cteq6mE.LHgrid";  
  // const string _pdfname = "CT10.LHgrid";  
  int iset = 0;

  LHAPDF::initPDFSet( _pdfname, iset );
  // initpdfset_(_pdfname.c_str());
  // initpdf_( iset );






  // do the convolution into a vector
  std::cout << "doing standalone convolution" << std::endl; 

  //  struct timeval atimer = appl_timer_start(); 

  std::vector<double>  xsec = g.vconvolute( evolvepdf_, alphaspdf_ ); 

  //  double atime = appl_timer_stop(atimer); 
  //  std::cout << "time " << atime << " ms" << std::endl;

  for ( int i=0 ; i<xsec.size() ; i++ ) std::cout << "xsec[" << i << "]\t= " << xsec[i] << std::endl;  





  // do the convolution into a TH1D

  //  atimer = appl_timer_start(); 
  TH1D*  hxsec = g.convolute( evolvepdf_, alphaspdf_ ); 
  //  atime = appl_timer_stop(atimer); 
  //  std::cout << "time " << atime << " ms" << std::endl;

  hxsec->SetLineColor(kRed);
  hxsec->SetMarkerColor(kRed);
  hxsec->SetMarkerStyle(20);
  hxsec->DrawCopy();
  gPad->SetLogy(true);

  gPad->Print("xsec.pdf");



  return 0;
}
